.. kwimage documentation master file, created by
   sphinx-quickstart on Sat Feb 16 21:34:45 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


:gitlab_url: https://gitlab.kitware.com/computer-vision/kwimage

Welcome to kwimage's documentation!
===================================

.. The __init__ files contains the top-level documentation overview
.. automodule:: kwimage.__init__
    :show-inheritance:

.. # Computed function usefulness
.. include:: function_usefulness.rst


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   kwimage

.. .. toctree::
..   kwarray



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
